import 'package:rook_users/rook_users.dart';
import 'package:shared_preferences/shared_preferences.dart';

/// Helper class to manage rook_users preferences.
class UsersPreferences {
  SharedPreferences? _preferences;

  final String _rookUser = 'rook_user';

  Future<bool> _init() async {
    _preferences ??= await SharedPreferences.getInstance();

    return true;
  }

  /// Saves the provided [RookUser] instance in preferences.
  ///
  /// This function will replace any existing values.
  Future<bool> saveRookUser(RookUser rookUser) async {
    if (_preferences == null) {
      await _init();
    }

    final saved = await _preferences!.setString(
      '${_rookUser}_${rookUser.type.name}',
      rookUser.toJson(),
    );

    return saved;
  }

  /// Retrieve the current [RookUser] from preferences. Or null if not found.
  Future<RookUser?> getRookUser(UserType userType) async {
    if (_preferences == null) {
      await _init();
    }

    final raw = _preferences!.getString('${_rookUser}_${userType.name}');

    if (raw != null) {
      return RookUser.fromJson(raw);
    } else {
      return null;
    }
  }

  /// Deletes the provided [UserType].
  Future<bool> deleteRookUser(UserType userType) async {
    if (_preferences == null) {
      await _init();
    }

    final success = await _preferences!.remove('${_rookUser}_${userType.name}');

    return success;
  }
}
