import 'dart:convert';

import 'package:rook_users/rook_users.dart';

/// This class represents a request to register a user in server.
///
/// * [client] - Client unique identifier.
/// * [rookUser] - User unique identifier.
class RegisterRookUserRequest {
  final String client;
  final RookUser rookUser;

  const RegisterRookUserRequest({required this.client, required this.rookUser});

  String toJson() {
    final map = {
      'client': client,
      'user_uuid': rookUser.id,
    };

    return jsonEncode(map);
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is RegisterRookUserRequest &&
          runtimeType == other.runtimeType &&
          client == other.client &&
          rookUser == other.rookUser;

  @override
  int get hashCode => client.hashCode ^ rookUser.hashCode;

  @override
  String toString() {
    return 'RegisterRookUserRequest{client: $client, userUUID: $rookUser}';
  }
}
