import 'package:http/http.dart' as http;
import 'package:rook_users/src/data/server/dto/register_rook_user_request.dart';
import 'package:rook_users/src/domain/enums/enums.dart';

import 'api_exception.dart';

/// Helper class to send users requests.
class UsersApi {
  final http.Client _client = http.Client();

  final String _url;

  UsersApi({required String url}) : _url = url;

  String get urlPostFix => '/api/v1';

  /// Registers the user in server.
  ///
  /// [request] - [RegisterRookUserRequest] instance.
  Future<bool> registerRookUser(RegisterRookUserRequest request) async {
    final uri = Uri.https(
      _url,
      '$urlPostFix/${getDestination(request.rookUser.type)}',
    );

    final response = await _client.post(
      uri,
      headers: {
        'Content-Type': 'application/json',
        'Accept': 'application/json',
      },
      body: request.toJson(),
    );

    if (response.statusCode == 201 || response.statusCode == 409) {
      return true;
    } else {
      throw ApiException(code: response.statusCode, message: response.body);
    }
  }

  String getDestination(UserType userType) {
    if (userType == UserType.healthConnect) {
      return 'google-user';
    }

    throw Exception('UserType: $userType is not valid');
  }
}
