import 'dart:convert';

import 'package:rook_users/src/domain/enums/enums.dart';

/// This class represents a registered user.
///
/// * [id] - Unique identifier.
/// * [type] - Ware the user is registered at.
class RookUser {
  final String id;
  final UserType type;

  const RookUser({
    required this.id,
    required this.type,
  });

  factory RookUser.fromJson(String json) {
    final map = jsonDecode(json) as Map<String, dynamic>;

    return RookUser(
      id: map['id'] as String,
      type: stringToUserType(map['type']),
    );
  }

  String toJson() {
    final map = {
      'id': id,
      'type': type.name,
    };

    return jsonEncode(map);
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is RookUser && runtimeType == other.runtimeType && id == other.id;

  @override
  int get hashCode => id.hashCode;

  @override
  String toString() {
    return 'RookUser{id: $id}';
  }
}
